@@ -162,7 +162,9 @@ def main():
                              "четырех значный формат 3.0.75.100 (не более 3 знаков на каждый разряд)"
                              "подробности в инструкции - раздел разработка расширений")
     parser.add_argument('--gui',
-                        help="режим работы интерфейса,"
+                        help="режим совместимости интерфейса 1С, переопределяет значение из исходников "
+                             "для расширений, если указан устанавливается в соответствующий реквизит. "
+                             "Допустимые значения:"
                              " допустимые значения 0 - Версия 8.2, 1 - Версия 8.2. Разрешить Такси,"
                              " 2- Такси. Разрешить Версия 8.2, 3 - Такси"
                              "для расширений устанавливается в соответствующий реквизит")
